==> adx-center-api-0.0.63-lzh-20220810.032301-12-sources.jar: cn/com/duiba/tuia/adx/center/api/req/ResourceLocationPageReq.java <==
package cn.com.duiba.tuia.adx.center.api.req;

import cn.com.duiba.tuia.ssp.center.api.dto.ReqPageQuery;

import java.util.List;

/**
 * 资源位分页查询
 *
 * @author weny.cai
 * @date 2018/12/3 11:15
 **/
public class ResourceLocationPageReq extends ReqPageQuery {

    private static final long serialVersionUID = -6226113025619915754L;
    /**
     * 搜索关键字 可以是资源位id或者名称
     */
    private String resourceSearchKey;

    private String groupSearchKey;

    private Long id;

    private String resourceName;

    private Integer advertType;

    private String groupName;

    private Long groupId;

    private Integer switchState;

    private String startDate;

    private String endDate;

    private String sort;

    private String order;

    private List<Long> groupIdList;

    public String getResourceSearchKey() {
        return resourceSearchKey;
    }

    public void setResourceSearchKey(String resourceSearchKey) {
        this.resourceSearchKey = resourceSearchKey;
    }

    public String getGroupSearchKey() {
        return groupSearchKey;
    }

    public void setGroupSearchKey(String groupSearchKey) {
        this.groupSearchKey = groupSearchKey;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public Long getGroupId() {
        return groupId;
    }

    public void setGroupId(Long groupId) {
        this.groupId = groupId;
    }

    public Integer getSwitchState() {
        return switchState;
    }

    public void setSwitchState(Integer switchState) {
        this.switchState = switchState;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getOrder() {
        return order;
    }

    public void setOrder(String order) {
        this.order = order;
    }

    public List<Long> getGroupIdList() {
        return groupIdList;
    }

    public void setGroupIdList(List<Long> groupIdList) {
        this.groupIdList = groupIdList;
    }
}

==> adx-center-api-0.0.75-lzh-20221026.034940-16-sources.jar: cn/com/duiba/tuia/adx/center/api/req/ResourceLocationPageReq.java <==
package cn.com.duiba.tuia.adx.center.api.req;

import cn.com.duiba.tuia.ssp.center.api.dto.ReqPageQuery;

import java.util.List;

/**
 * 资源位分页查询
 *
 * @author weny.cai
 * @date 2018/12/3 11:15
 **/
public class ResourceLocationPageReq extends ReqPageQuery {

    private static final long serialVersionUID = -6226113025619915754L;
    /**
     * 搜索关键字 可以是资源位id或者名称
     */
    private String resourceSearchKey;

    private String groupSearchKey;

    private Long id;

    private String resourceName;

    private Integer advertType;

    private String groupName;

    private Long groupId;

    private Integer switchState;

    private String startDate;

    private String endDate;

    private String sort;

    private String order;

    private List<Long> groupIdList;

    //外部广告位id
    private String externPosId;

    //资源位id列表
    private List<Long> resourceIds;

    public String getResourceSearchKey() {
        return resourceSearchKey;
    }

    public void setResourceSearchKey(String resourceSearchKey) {
        this.resourceSearchKey = resourceSearchKey;
    }

    public String getGroupSearchKey() {
        return groupSearchKey;
    }

    public void setGroupSearchKey(String groupSearchKey) {
        this.groupSearchKey = groupSearchKey;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public Long getGroupId() {
        return groupId;
    }

    public void setGroupId(Long groupId) {
        this.groupId = groupId;
    }

    public Integer getSwitchState() {
        return switchState;
    }

    public void setSwitchState(Integer switchState) {
        this.switchState = switchState;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getOrder() {
        return order;
    }

    public void setOrder(String order) {
        this.order = order;
    }

    public List<Long> getGroupIdList() {
        return groupIdList;
    }

    public void setGroupIdList(List<Long> groupIdList) {
        this.groupIdList = groupIdList;
    }

    public String getExternPosId() {
        return externPosId;
    }

    public void setExternPosId(String externPosId) {
        this.externPosId = externPosId;
    }

    public List<Long> getResourceIds() {
        return resourceIds;
    }

    public void setResourceIds(List<Long> resourceIds) {
        this.resourceIds = resourceIds;
    }
}
